==> 0.5.6.tar.gz: lib/widget/vgk-card-horizontal-with-popup-widget/vgk-card-horizontal-with-popup-content-widget.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-with-popup-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-alert_widget/vgk-alert-style.dart';
import 'package:vgkprogaming/widget/vgk-alert_widget/vgk-alert_widget.dart';
import 'package:vgkprogaming/widget/vgk-alert_widget/vgk-constants.dart';

vgkCardHorizontalWithPopupContentWidget(context, String title,
    List<VgkCardHorizontalWithPopupContentModel> data, animation, startColor) {
  final List<Widget> listViews = <Widget>[];
  data.forEach((element) {
    listViews.add(
      new Padding(
        padding: const EdgeInsets.all(0),
        child: Row(
          children: <Widget>[
            Expanded(
              child: Padding(
                padding: const EdgeInsets.only(left: 8, right: 8, top: 4),
                child: Column(
                  children: <Widget>[
                    Row(
                      children: <Widget>[
                        Container(
                          height: 48,
                          width: 4,
                          decoration: BoxDecoration(
                            color:
                                VgkProGamingTheme.primaryColor.withOpacity(0.5),
                            borderRadius:
                                BorderRadius.all(Radius.circular(4.0)),
                          ),
                        ),
                        Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: Column(
                            mainAxisAlignment: MainAxisAlignment.center,
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: <Widget>[
                              Padding(
                                padding:
                                    const EdgeInsets.only(left: 4, bottom: 2),
                                child: Text(
                                  element.key,
                                  textAlign: TextAlign.center,
                                  style: VgkProGamingTheme.h2,
                                ),
                              ),
                              Row(
                                mainAxisAlignment: MainAxisAlignment.center,
                                crossAxisAlignment: CrossAxisAlignment.end,
                                children: <Widget>[
                                  SizedBox(
                                    width: 28,
                                    height: 28,
                                    child: Icon(
                                      Icons.queue_play_next,
                                      color: VgkProGamingTheme.primaryColor
                                          .withOpacity(0.5),
                                    ),
                                  ),
                                  Padding(
                                    padding: const EdgeInsets.only(
                                        left: 4, bottom: 3),
                                    child: Text(
                                      '${(element.value)}',
                                      textAlign: TextAlign.center,
                                      style: VgkProGamingTheme.h1,
                                    ),
                                  ),
                                ],
                              )
                            ],
                          ),
                        )
                      ],
                    ),
                  ],
                ),
              ),
            ),
          ],
        ),
      ),
    );
  });
  final alertStyle = VgkAlertStyle(
    animationType: AnimationType.fromTop,
    isCloseButton: true,
    isOverlayTapDismiss: true,
    descStyle: VgkProGamingTheme.h1,
    animationDuration: Duration(milliseconds: 400),
  );
  VgkAlertWidget(
    context: context,
    style: alertStyle,
    title: title,
    content: Column(
      children: listViews,
    ),
    buttons: [],
  ).show();
}

==> 0.9.3.tar.gz: lib/widget/vgk-card-horizontal-with-popup-widget/vgk-card-horizontal-with-popup-content-widget.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:vgkprogaming/model/vgk-card-horizontal-with-popup-model.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';
import 'package:vgkprogaming/widget/vgk-alert_widget/vgk-alert-style.dart';
import 'package:vgkprogaming/widget/vgk-alert_widget/vgk-alert_widget.dart';
import 'package:vgkprogaming/widget/vgk-alert_widget/vgk-constants.dart';

vgkCardHorizontalWithPopupContentWidget(
    context,
    String title,
    List<VgkCardHorizontalWithPopupContentModel> data,
    animation,
    primaryColor) {
  final List<Widget> listViews = <Widget>[];
  data.forEach((element) {
    listViews.add(
      new Padding(
        padding: const EdgeInsets.all(0),
        child: Row(
          children: <Widget>[
            Expanded(
              child: Padding(
                padding: const EdgeInsets.only(left: 8, right: 8, top: 4),
                child: Column(
                  children: <Widget>[
                    Row(
                      children: <Widget>[
                        Container(
                          height: 48,
                          width: 4,
                          decoration: BoxDecoration(
                            color: HexColor(primaryColor).withOpacity(0.5),
                            borderRadius:
                                BorderRadius.all(Radius.circular(4.0)),
                          ),
                        ),
                        Padding(
                          padding: const EdgeInsets.all(8.0),
                          child: Column(
                            mainAxisAlignment: MainAxisAlignment.center,
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: <Widget>[
                              Padding(
                                padding:
                                    const EdgeInsets.only(left: 4, bottom: 2),
                                child: Text(
                                  element.key,
                                  textAlign: TextAlign.center,
                                  style: VgkProGamingTheme.h2(primaryColor),
                                ),
                              ),
                              Row(
                                mainAxisAlignment: MainAxisAlignment.center,
                                crossAxisAlignment: CrossAxisAlignment.end,
                                children: <Widget>[
                                  SizedBox(
                                    width: 28,
                                    height: 28,
                                    child: Icon(
                                      Icons.queue_play_next,
                                      color: HexColor(primaryColor)
                                          .withOpacity(0.5),
                                    ),
                                  ),
                                  Padding(
                                    padding: const EdgeInsets.only(
                                        left: 4, bottom: 3),
                                    child: Text(
                                      '${(element.value)}',
                                      textAlign: TextAlign.center,
                                      style: VgkProGamingTheme.h1(primaryColor),
                                    ),
                                  ),
                                ],
                              )
                            ],
                          ),
                        )
                      ],
                    ),
                  ],
                ),
              ),
            ),
          ],
        ),
      ),
    );
  });
  final alertStyle = VgkAlertStyle(
    animationType: AnimationType.fromTop,
    isCloseButton: true,
    isOverlayTapDismiss: true,
    descStyle: VgkProGamingTheme.h1(primaryColor),
    animationDuration: Duration(milliseconds: 400),
  );
  VgkAlertWidget(
    context: context,
    style: alertStyle,
    title: title,
    content: Column(
      children: listViews,
    ),
    buttons: [],
  ).show(primaryColor);
}
